pub struct Path { /* private fields */ }Expand description
The current path of the serialization or deserialization.
This type is stored in the state and can be retrieved at any point. By
inspecting the segments a type can figure out where
it’s invoked from. It formats as servers[1].host.
The PathLayer also attaches the path to errors (see
Error::attachment) where it shows up as (path: servers[1].host) in
the error message.
Implementations