pub struct PathLayer { /* private fields */ }Expand description
A layer that tracks the current Path in the state.
The layer works for serialization (it implements
deser::ser::Layer) and deserialization (it implements
deser::de::Layer). It attaches the path to errors which do not have
one (see Error::attachment).
During deserialization the path is also correct for values which are buffered and replayed (for instance by internally tagged enums).
Layers see the path of the current event if they are added after the path layer. This also means that the errors of such layers get the path of the event they reject attached, so the path layer should typically be added first.
Implementations